;
;  D I S P L A Y 
;  -------------
;
;
; Pro rizeni sedmisegmentoveho displeje na pripravcich je pouzit
; obvod M5480B7. Obvod obsahuje posuvny registr a zachytny registr, jehoz
; vystupy primo ovladaji jednotlive segmentovky displeje. Data (to, co
; pozadujeme na displeji zobrazit) vstupuji do obvodu seriove pres bity
; P1.0 (hodiny) a P1.1 (seriova data). Jednotlive bity se zapisuji
; nabeznou hranou hodinoveho signalu.
;
; Seriova data maji konstantni delku 36 bitu. Prvni bit je vzdy jednickovy
; a ridi prepsani informace z posuvneho registru do zachytneho registru.
; K prepsani dojde tehdy, kdyz se tento bit dostane na konec posuvneho
; registru (tzn. kdyz vsech 36 bitu je jiz v posuvnem registru). Tim se
; zamezuje problikavani segmentu behem zapisu dat.
;
; Data maji nasledujici strukturu:
;
;      1 X g3 f3 e3 d3 c3 b3 a3  X X X g2 f2 e2 d2 X X ...
;      X X c2 b2 a2 g1 f1 e1  X d1 X X c1 b1 a1  X X X
;
; 1 - log. 1
; X - znamena: na tomto bitu nezalezi (muze byt 0 nebo 1).
; a,...,g - segmenty dle obr.
;
;
;   segmentovka 3    segmentovka 2    segmentovka 1
;   --------------   --------------   --------------
;  |       a3     | |      a2      | |       a1     |
;  |      ----    | |      ----    | |       ----   |
;  |  f3 /g3 / b3 | |  f2 /g2 / b2 | |  f1 /g1 / b1 |
;  |     ----     | |     ----     | |     ----     |
;  | e3 /   / c3  | | e2 /   / c2  | | e1 /   / c1  |
;  |    ----      | |    ----      | |    ----      |
;  |     d3       | |     d2       | |     d1       |
;   --------------   --------------   --------------
;
;       !!! DESETINNE TECKY NEJSOU ZAPOJENY !!!
;
; TVARY ZNAKU
;
; format: 
;                       | x | g | f | e | d | c | b | a |
;  napr.: char_0 = 3fh  | 0 | 0 | 1 | 1 | 1 | 1 | 1 | 1 |
;
; cisla
;
char_0      equ 3fh
char_1      equ 06h
char_2      equ 5bh
char_3      equ 4fh
char_4      equ 66h
char_5      equ 6dh
char_6      equ 7dh
char_7      equ 07h
char_8      equ 7fh
char_9      equ 6fh
;
; pismena
;
char_A      equ 77h
char_b      equ 7ch
char_C      equ 39h
char_d      equ 5eh
char_E      equ 79h
char_F      equ 71h
char_H      equ 76h
char_J      equ 1Fh
char_L      equ 38h
char_n      equ 54h
char_o      equ 5ch
char_P      equ 63h
char_r      equ 50h
char_S      equ 6dh
char_u      equ 1ch
char_Y      equ 6eh
;
; specialni znaky
;
char_blank  equ 00h
char_minus  equ 40h
;



; haf
org 8000h
ljmp start
org 8100h


; free

start:
           mov   r3,#char_1 
           mov   r2,#char_7 
           mov   r1,#char_4 


call resetdisp
call wait

setb c
call clk
clr c
call clk
mov a, r3
call loadnumber
mov a, r2
call loadnumber
mov a, r1
call loadnumber
clr c
call clk
call clk
call clk
call clk
call clk

haf:
	clr p1.3
	setb p1.2

	call wait

	clr p1.2
	setb p1.3

	call wait
jmp haf


konec: sjmp konec

; free


clk: ; input: carry

;	jnc LElse:
;		clr p1.1
;		jmp LEnd
;	LElse:
;		setb p1.1
;
;	LEnd:
	mov p1.1, c	
	
	clr p1.0
	setb p1.0
ret

resetdisp:
	call init_disp
	call clear_disp
ret

loadnumber: ; input a
	rlc a	
	mov r3, #11
	loop4:
		rlc a
		
		call clk
	djnz r3, loop4

ret

init_disp:
	mov r3, #036
	clr c
	loop0:
		call clk
		
	djnz r3, loop0
ret

clear_disp:
	setb c
	call clk

;	clr c

	mov r3, #035
	loop1:
		call clk
		
	djnz r3, loop1
ret

wait:

;	mov r3, #0FF
;	mov r2, #0FF
;	waitX:
;		add r2, 1
;		addc r3, 1
;	jnz r3, waitX
;ret
	mov r3, #0FFh
	wait0:
		mov r2, #0
		wait1:
		djnz r2, wait1

	djnz r3, wait0

ret

end
